@@ -332,15 +332,6 @@ class VerifyProfilesAction(base.TripleOAction):
         bm_nodes = {node['uuid']: node for node in self.nodes
                     if node['provision_state'] in ('available', 'active')}
 
-        if not bm_nodes:
-            message = ('Error: There are no nodes in an available '
-                       'or active state and with maintenance mode off.')
-            return_value = {
-                'errors': [message],
-                'warnings': [],
-            }
-            return actions.Result(error=return_value)
-
         free_node_caps = {uu: self._node_get_capabilities(node)
                           for uu, node in bm_nodes.items()}
 
@@ -438,7 +429,7 @@ class CheckNodesCountAction(base.TripleOAction):
         requested_count = 0
 
         for param, default in self.default_role_counts.items():
-            if self.stack:
+            if self.stack and self.stack.status != 'FAILED':
                 try:
                     current = int(self.stack['parameters'][param])
                 except KeyError:
